
.. include:: substitutions.rst
|logo|
===================================

An analytical framework for the Greek and European Power&Gas, System Operation ("SO") & Market Exchange ("Ex").
Version |version|


Check out the :ref:`core_concepts` section for further information, including
how to :ref:`install <installation>`  the project.

.. note::

   This project documentation has recently changed, from a simple README, to a dedicated documentation page, which, although complete, may leave some questions unanswered, especially to newcomers.
    In such a case, feel free to consult with the `Old readme file <https://github.com/ThanosGkou/exso/blob/main/README_v0.0.0.md>`_ in case it helps.


Contents
--------

.. toctree::
   :maxdepth: 2

   What's New <whats_new>
   Installation and Upgrade <installation>
   Core Concepts <core_concepts>
   api




